@@ -1,5 +1,6 @@
 from .kinetic_model import KineticModel
-from . import co2_to_meoh
+from .reverse_kinetic_model import ReverseKineticModel
+from . import co2_to_c1
 from . import co2_fts
 from . import mto
 from . import tandem
