@@ -1,9 +1,9 @@
 import numpy as np
 from numpy.typing import NDArray
 
-import catrxneng.species as species
+from .. import species as species
 from .kinetic_model import KineticModel
-import catrxneng.quantities as quant
+from .. import quantities as quant
 
 
 class CompositeKineticModel(KineticModel):
@@ -14,14 +14,28 @@ class CompositeKineticModel(KineticModel):
 
     kinetic_models: list[KineticModel]
 
+    def __init_subclass__(cls):
+        cls.REACTIONS = {
+            id: REACTION_CLASS
+            for KM in cls.KINETIC_MODEL_CLASSES
+            for id, REACTION_CLASS in KM.REACTIONS.items()
+        }
+        super().__init_subclass__()
+
     def __init__(
-        self, catalyst_frac: NDArray, T: quant.Temperature | None = None, **kwargs
+        self,
+        catalyst_frac: NDArray,
+        child_kinetic_models_kwargs: list = [],
+        T: quant.Temperature | None = None,
     ):
-        super().__init__(T=T, **kwargs)
         self.catalyst_frac = np.asarray(catalyst_frac)
         self.kinetic_models: list[KineticModel] = [
-            KM(T=T, **kwargs) for KM in self.KINETIC_MODEL_CLASSES
+            KM(T=T, **kwargs)
+            for KM, kwargs in zip(
+                self.KINETIC_MODEL_CLASSES, child_kinetic_models_kwargs
+            )
         ]
+        self.T = T
         self.map_child_components_to_parent_components = [
             [self.comp_list().index(comp) for comp in KM.comp_list()]
             for KM in self.KINETIC_MODEL_CLASSES
@@ -33,10 +47,6 @@ class CompositeKineticModel(KineticModel):
 
     @T.setter
     def T(self, value):
-        if value is not None and (not hasattr(self, "_T") or value.si != self._T.si):
-            self._T = value
-            try:
-                for kinetic_model in self.kinetic_models:
-                    kinetic_model.T = value
-            except AttributeError:
-                pass
+        self._T = value
+        for kinetic_model in self.kinetic_models:
+            kinetic_model.T = value
