@@ -20,9 +20,9 @@ class PlotlyPlot:
     COLORS = [
         "red",
         "blue",
-        "limegreen",
+        "LightSeaGreen",
         "magenta",
-        "#F09C2E",  # orange
+        "Coral",  # orange
         "gray",
         "black",
         "lightblue",
