@@ -1,11 +1,14 @@
 import numpy as np
 from scipy.integrate import solve_ivp
+from copy import deepcopy
+import pandas as pd
+from typing import Any
 
 from .. import utils
 from .reactor import Reactor
 from catrxneng.kinetic_models import KineticModel
 from catrxneng.species.gas_mixture import GasMixture
-import catrxneng.quantities as quant
+from .. import quantities as quant
 
 
 class PFR(Reactor):
@@ -17,7 +20,7 @@ class PFR(Reactor):
         whsv: quant.WHSV | None = None,
         mcat: quant.Mass | None = None,
         F0: quant.MolarFlowRate | None = None,
-        **kinetic_model_kwargs,
+        kinetic_model_kwargs: dict[str, Any] = {},
     ):
         super().__init__()
         self.kinetic_model_class = kinetic_model_class
@@ -28,7 +31,7 @@ class PFR(Reactor):
         self.p0 = p0
         feed = GasMixture(components=self.kinetic_model_class.COMPONENTS, p=self.p0)
         self.P = quant.Pressure(si=np.sum(p0.si))
-        self.P_bar = self.P.bar
+        # self.P_bar = self.P.bar
         self.y0 = utils.divide(p0, self.P)
         self.whsv = whsv
         self.mcat: quant.Mass = quant.Mass(g=1) if mcat is None else mcat
@@ -50,7 +53,7 @@ class PFR(Reactor):
         self.check_components()
 
     def dFdw(self, x, F: np.ndarray) -> np.array:
-        p_array = F / np.sum(F) * self.P_bar
+        p_array = F / np.sum(F) * getattr(self.P, self.kinetic_model.pressure_units)
         return self.kinetic_model.rate_equations(p_array)
 
     def dfdx(self, x, f: np.ndarray) -> np.array:
@@ -71,8 +74,8 @@ class PFR(Reactor):
     def _solve_dimensional(self, points: int, method: str):
         w_span = (0, self.mcat.g)
         w_eval = np.linspace(0, self.mcat.g, points)
-        F0 = self.F0.molh
-        solution = solve_ivp(self.dFdw, w_span, F0, t_eval=w_eval, method=method)
+        F0_molh = self.F0.molh
+        solution = solve_ivp(self.dFdw, w_span, F0_molh, t_eval=w_eval, method=method)
         self.w = quant.Mass(g=solution.t)
         self.F = quant.MolarFlowRate(molh=solution.y, keys=self.F0.keys)
 
@@ -100,9 +103,16 @@ class PFR(Reactor):
             self._solve_dimensional(points=points, method=method)
         y_si = np.divide(self.F.si, np.sum(self.F.si, axis=0))
         self.y = quant.Fraction(si=y_si, keys=self.F0.keys)
+        self.Ft = quant.MolarFlowRate(si=np.sum(self.F.si, axis=0))
+        self.Ft_active = self.Ft - self.F["inert"]
+        self.y_active = self.F / self.Ft_active
+        self.y_active.delete("inert")
+        self.dF_limiting_reactant = (
+            self.F[self.kinetic_model.LIMITING_REACTANT]
+            - self.F0[self.kinetic_model.LIMITING_REACTANT]
+        )
         self.conversion = utils.divide(
-            self.F0[self.kinetic_model.LIMITING_REACTANT]
-            - self.F[self.kinetic_model.LIMITING_REACTANT],
+            -self.dF_limiting_reactant,
             self.F0[self.kinetic_model.LIMITING_REACTANT],
         )
         spacetime = utils.divide(self.w.g, self.Ft0_active.smLh)
@@ -111,10 +121,11 @@ class PFR(Reactor):
         vol_flow_rate = self.Ft0.si * quant.R.si * self.T.si / self.P.si
         self.vol_flow_rate = quant.VolumetricFlowRate(si=vol_flow_rate)
         self.p = self.y * self.P
-        self.rate = self.kinetic_model.calculate_rates(self.p)
+        self.rate = self.kinetic_model.compute_rates(self.p)
+        self.generate_df()
 
     @property
-    def conv_rel_to_eq_conv(self):
+    def conversion_relative_to_equil_conversion(self):
         self.kinetic_model.equilibrate(p0=self.p0, T=self.T)
         return self.conversion[-1] / self.kinetic_model.eq_conversion
 
