@@ -7,6 +7,8 @@ from catrxneng.kinetic_models import KineticModel
 class Reactor:
 
     kinetic_model_class: type[KineticModel]
+    kinetic_model: KineticModel
+    aggregate_flow_rates: pd.DataFrame
 
     @property
     def molar_flowrate_df_molh(self):
@@ -23,26 +25,20 @@ class Reactor:
     def molar_flowrate_df_molh(self, value):
         self.molar_flowrate_df_molh_cache = value
 
-    def __init__(self):
-        from catrxneng.quantities import MolarFlowRate
-
-        self.aggregate_flow_rates: dict[str, MolarFlowRate] = {}
-
     def check_components(self):
         if self.p0.size != len(self.kinetic_model.COMPONENTS):
             raise ValueError(
                 "Number of components for reactor and rate model do not match."
             )
 
-    def plot(self, x, y, names, modes, xlabel, ylabel, title=None):
-        fig = go.Figure()
-        for i in range(len(y)):
-            trace = go.Scatter(x=x[i], y=[i], mode=modes[i], name=names[i])
-            fig.add_trace(trace)
-        fig.update_layout(
-            title=dict(text=f"<b>{title}</b>", x=0.5),
-            xaxis_title=f"<b>{xlabel}</b>",
-            yaxis_title=f"<b>{ylabel}</b>",
-            width=800,
+    def generate_df(self):
+        from catrxneng.utils import compute_molfracs_from_molar_flowrates
+
+        self.df = pd.DataFrame(
+            {f"{key}_dnstr_molh": self.F[key].molh for key in self.F.keys}
         )
-        fig.show()
+        self.df = compute_molfracs_from_molar_flowrates(
+            df=self.df, KM=self.kinetic_model_class
+        )
+        for key in self.p.keys:
+            self.df[f"{key}_dnstr_bar"] = self.df[f"{key}_dnstr_molfrac"] * self.P.bar
