@@ -1,6 +1,6 @@
 from .species import Species
-import catrxneng.utils.equations as eqn
-import catrxneng.quantities as quant
+from ..utils import equations as eqn
+from .. import quantities as quant
 
 
 class CH4(Species):
