@@ -1,5 +1,5 @@
-import catrxneng.utils.equations as eqn
-import catrxneng.quantities as quant
+from ..utils import equations as eqn
+from .. import quantities as quant
 from .species import Species
 
 
@@ -27,13 +27,13 @@ class CO2(Species):
     ]
 
     @classmethod
-    def Hf_gas(cls, T):
+    def Hf_gas_shomate(cls, T) -> quant.Energy:
         return eqn.Hf_shomate(T, cls.NIST_THERMO_PARAMS[0])
 
     @classmethod
-    def S_gas(cls, T):
+    def S_gas_shomate(cls, T) -> quant.Entropy:
         return eqn.S_shomate(T, cls.NIST_THERMO_PARAMS[0])
 
     @classmethod
-    def Cp_gas(cls, T):
+    def Cp_gas(cls, T) -> quant.HeatCapacity:
         return eqn.Cp_shomate(T, cls.NIST_THERMO_PARAMS[0])
