@@ -1,5 +1,5 @@
 from .species import Species
-import catrxneng.quantities as quant
+from .. import quantities as quant
 
 
 class DME(Species):
@@ -25,6 +25,6 @@ class DME(Species):
     @classmethod
     def Cp_gas(cls, T: quant.Temperature) -> quant.HeatCapacity:
         if 298 <= T.K <= 1000:
-            cp = -5e-5 * T.K * T.K + 0.173 * T.K + 18.717
+            cp = -5e-5 * T.K * T.K + 0.173 * T.K + 18.717  # NIST
             return quant.HeatCapacity(JmolK=cp)
         raise ValueError("Temperature is out of range.")
