@@ -1,6 +1,6 @@
 from .species import Species
-import catrxneng.quantities as quant
-import catrxneng.utils.equations as eqn
+from .. import quantities as quant
+from ..utils import equations as eqn
 
 
 class H2(Species):
@@ -26,11 +26,11 @@ class H2(Species):
     ]
 
     @classmethod
-    def Hf_gas(cls, T):
+    def Hf_gas_shomate(cls, T):
         return eqn.Hf_shomate(T, cls.NIST_THERMO_PARAMS[0])
 
     @classmethod
-    def S_gas(cls, T):
+    def S_gas_shomate(cls, T):
         return eqn.S_shomate(T, cls.NIST_THERMO_PARAMS[0])
 
     @classmethod
