@@ -1,6 +1,6 @@
+from .. import quantities as quant
 from .species import Species
 
 
 class Inert(Species):
     CLASS = "inert"
-    MOL_WEIGHT = 0
