@@ -1,4 +1,4 @@
-from catrxneng import utils
+from .. import utils
 from .species import Species
 from ..quantities import *
 
