@@ -1,10 +1,10 @@
 import numpy as np
-from typing import Any
+from typing import cast
 
-import catrxneng.quantities as quant
+from .. import quantities as quant
 
 
-def Hf_shomate(T, params):
+def Hf_shomate(T, params) -> quant.Energy:
     from catrxneng.quantities import Energy
 
     t = T.K / 1000
@@ -20,7 +20,7 @@ def Hf_shomate(T, params):
     return Energy(kJmol=dHf)
 
 
-def S_shomate(T, params):
+def S_shomate(T, params) -> quant.Entropy:
     from catrxneng.quantities import Entropy
 
     t = T.K / 1000
@@ -35,7 +35,7 @@ def S_shomate(T, params):
     return Entropy(JmolK=S)
 
 
-def Cp_shomate(T, params):
+def Cp_shomate(T, params) -> quant.HeatCapacity:
     from catrxneng.quantities import HeatCapacity
 
     t = T.K / 1000
@@ -50,6 +50,6 @@ def Cp_shomate(T, params):
 
 
 def vant_hoff_eqn(
-    x_ref: Any, dH: quant.Energy, T: quant.Temperature, Tref: quant.Temperature
-):
-    return x_ref * np.exp(dH / quant.R * (1 / Tref - 1 / T))
+    x_ref: float, dH: quant.Energy, T: quant.Temperature, Tref: quant.Temperature
+) -> float:
+    return x_ref * cast(float, np.exp(dH.si / quant.R.si * (1 / Tref.si - 1 / T.si)))
